@@ -9,7 +9,7 @@ def test_one_well():
                 'XXX': {'x': 1},
             },
     }
-    with raises(ConfigError, match='XXX'):
+    with raises(LayoutError, match='XXX'):
         wells_from_config(config)
 
     config = {
@@ -92,7 +92,7 @@ def test_one_block():
                 'err': {}
             },
     }
-    with raises(ConfigError, match="err"):
+    with raises(LayoutError, match="err"):
         wells_from_config(config_err)
 
     config_0x0 = {
@@ -102,7 +102,7 @@ def test_one_block():
                 },
             },
     }
-    with raises(ConfigError, match="0x0"):
+    with raises(LayoutError, match="0x0"):
         wells_from_config(config_0x0)
 
     config_0x1 = {
@@ -112,7 +112,7 @@ def test_one_block():
                 },
             },
     }
-    with raises(ConfigError, match="0x1"):
+    with raises(LayoutError, match="0x1"):
         wells_from_config(config_0x1)
 
     config_1x0 = {
@@ -122,7 +122,7 @@ def test_one_block():
                 },
             },
     }
-    with raises(ConfigError, match="1x0"):
+    with raises(LayoutError, match="1x0"):
         wells_from_config(config_1x0)
 
     config_1x1 = {
@@ -244,7 +244,7 @@ def test_one_row_col():
                 '1': {'y': 1},
             },
     }
-    with raises(ConfigError, match='1'):
+    with raises(LayoutError, match='1'):
         wells_from_config(config)
 
     config = {
@@ -255,7 +255,7 @@ def test_one_row_col():
                 'A': {'y': 1},
             },
     }
-    with raises(ConfigError, match='A'):
+    with raises(LayoutError, match='A'):
         wells_from_config(config)
 
     config = {
@@ -345,6 +345,20 @@ def test_row_range():
             (2,0): {'x': 1, 'y': 1},
     }
 
+    config = {
+            'row': {
+                'A-C': {'x': 1},
+            },
+            'col': {
+                '1': {'y': 1},
+            },
+    }
+    assert wells_from_config(config) == {
+            (0,0): {'x': 1, 'y': 1},
+            (1,0): {'x': 1, 'y': 1},
+            (2,0): {'x': 1, 'y': 1},
+    }
+
     config = {
             'row': {
                 'A,B,...,C': {'x': 1},
@@ -374,6 +388,20 @@ def test_col_range():
             (0,2): {'x': 1, 'y': 1},
     }
 
+    config = {
+            'row': {
+                'A': {'x': 1},
+            },
+            'col': {
+                '1-3': {'y': 1},
+            },
+    }
+    assert wells_from_config(config) == {
+            (0,0): {'x': 1, 'y': 1},
+            (0,1): {'x': 1, 'y': 1},
+            (0,2): {'x': 1, 'y': 1},
+    }
+
     config = {
             'row': {
                 'A': {'x': 1},
@@ -394,7 +422,7 @@ def test_row_without_col():
                 'A': {'x': 1},
             },
     }
-    with raises(ConfigError, match="row"):
+    with raises(LayoutError, match="row"):
         wells_from_config(config)
 
     config = {
@@ -432,7 +460,7 @@ def test_col_without_row():
                 '1': {'y': 1},
             },
     }
-    with raises(ConfigError, match="col"):
+    with raises(LayoutError, match="col"):
         wells_from_config(config)
 
     config = {
@@ -560,7 +588,7 @@ def test_irow_without_col():
                 'A': {'x': 1},
             },
     }
-    with raises(ConfigError, match="irow"):
+    with raises(LayoutError, match="irow"):
         wells_from_config(config)
 
     config = {
@@ -643,7 +671,7 @@ def test_icol_without_row():
                 '1': {'y': 1},
             },
     }
-    with raises(ConfigError, match="icol"):
+    with raises(LayoutError, match="icol"):
         wells_from_config(config)
 
     config = {
