@@ -4,9 +4,9 @@
 File format for 96-well plate layouts.
 """
 
-__version__ = '3.2.1'
+__version__ = '3.4.0'
 
 from .util import *
 from .file import *
-from .plot import show
+from .plot import show, UsageError
 from . import plot
